
django-haweb
==================

Django app meant to serve a frontend to enable users to issue Domotic commands to
any server running django_hautomation module.

This module providesm, through a web interface, an easy way issue domotic commands, as well as
create custom domotic dashboards. Each dashboard has a set of domotic controls to which user 
can issue domotic commands.

The module belongs to the Home Automation Python Project, you can find further documentation about 
it here http://blog.digitalhigh.es/home-automation-python-project/

Also on this link there is documentation about this module:

http://blog.digitalhigh.es/home-automation-python-project/django-haweb/